@@ -7,6 +7,7 @@ import (
 	"os"
 	"path/filepath"
 	"sync"
+	"syscall"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
@@ -45,7 +46,7 @@ func requireHeader(t *testing.T, r *http.Request, header, want string) {
 	require.Equal(t, want, r.Header.Get(header))
 }
 
-// TODO: improve all tests below by checking wether the mocked handlers
+// TODO: improve all tests below by checking whether the mocked handlers
 // were called or not.
 
 func TestRunPipe_ModeBinary(t *testing.T) {
@@ -330,9 +331,7 @@ func TestRunPipe_ArtifactoryDown(t *testing.T) {
 	})
 
 	require.NoError(t, Pipe{}.Default(ctx))
-	err = Pipe{}.Publish(ctx)
-	require.Error(t, err)
-	require.Contains(t, err.Error(), "connection refused")
+	require.ErrorIs(t, Pipe{}.Publish(ctx), syscall.ECONNREFUSED)
 }
 
 func TestRunPipe_TargetTemplateError(t *testing.T) {
