@@ -27,23 +27,23 @@ func TestDescription(t *testing.T) {
 }
 
 func TestNameWithDash(t *testing.T) {
-	require.Equal(t, formulaNameFor("some-binary"), "SomeBinary")
+	require.Equal(t, "SomeBinary", formulaNameFor("some-binary"))
 }
 
 func TestNameWithUnderline(t *testing.T) {
-	require.Equal(t, formulaNameFor("some_binary"), "SomeBinary")
+	require.Equal(t, "SomeBinary", formulaNameFor("some_binary"))
 }
 
 func TestNameWithDots(t *testing.T) {
-	require.Equal(t, formulaNameFor("binaryv0.0.0"), "Binaryv000")
+	require.Equal(t, "Binaryv000", formulaNameFor("binaryv0.0.0"))
 }
 
 func TestNameWithAT(t *testing.T) {
-	require.Equal(t, formulaNameFor("some_binary@1"), "SomeBinaryAT1")
+	require.Equal(t, "SomeBinaryAT1", formulaNameFor("some_binary@1"))
 }
 
 func TestSimpleName(t *testing.T) {
-	require.Equal(t, formulaNameFor("binary"), "Binary")
+	require.Equal(t, "Binary", formulaNameFor("binary"))
 }
 
 var defaultTemplateData = templateData{
@@ -313,6 +313,8 @@ func TestFullPipe(t *testing.T) {
 								{Name: "zsh", Type: "optional"},
 								{Name: "bash", Version: "3.2.57"},
 								{Name: "fish", Type: "optional", Version: "v1.2.3"},
+								{Name: "powershell", Type: "optional", OS: "mac"},
+								{Name: "ash", Version: "1.0.0", OS: "linux"},
 							},
 							Conflicts:   []string{"gtk+", "qt"},
 							Service:     "run foo/bar\nkeep_alive true",
