@@ -86,6 +86,7 @@ func TestPrefetcher(t *testing.T) {
 func TestRunPipe(t *testing.T) {
 	for _, tt := range []struct {
 		name                 string
+		expectDefaultErrorIs error
 		expectRunErrorIs     error
 		expectPublishErrorIs error
 		nix                  config.Nix
@@ -100,6 +101,18 @@ func TestRunPipe(t *testing.T) {
 				},
 			},
 		},
+		{
+			name:                 "invalid license",
+			expectDefaultErrorIs: errInvalidLicense,
+			nix: config.Nix{
+				IDs:     []string{"foo"},
+				License: "mitt",
+				Repository: config.RepoRef{
+					Owner: "foo",
+					Name:  "bar",
+				},
+			},
+		},
 		{
 			name: "deps",
 			nix: config.Nix{
@@ -205,6 +218,20 @@ func TestRunPipe(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "zip-and-tar",
+			nix: config.Nix{
+				Name:        "foozip",
+				IDs:         []string{"zip-and-tar"},
+				Description: "my test",
+				Homepage:    "https://goreleaser.com",
+				License:     "mit",
+				Repository: config.RepoRef{
+					Owner: "foo",
+					Name:  "bar",
+				},
+			},
+		},
 		{
 			name:             "unibin",
 			expectRunErrorIs: ErrMultipleArchivesSamePlatform,
@@ -483,6 +510,11 @@ func TestRunPipe(t *testing.T) {
 					}
 					createFakeArtifact("wrapped-in-dir", goos, goarch, "", "", "tar.gz", map[string]any{artifact.ExtraWrappedIn: "./foo"})
 					createFakeArtifact("foo-zip", goos, goarch, "v1", "", "zip", nil)
+					if goos == "darwin" {
+						createFakeArtifact("zip-and-tar", goos, goarch, "v1", "", "zip", nil)
+					} else {
+						createFakeArtifact("zip-and-tar", goos, goarch, "v1", "", "tar.gz", nil)
+					}
 				}
 			}
 
@@ -510,12 +542,18 @@ func TestRunPipe(t *testing.T) {
 			}
 
 			// default
+			if tt.expectDefaultErrorIs != nil {
+				err := bpipe.Default(ctx)
+				require.ErrorAs(t, err, &tt.expectDefaultErrorIs)
+				return
+
+			}
 			require.NoError(t, bpipe.Default(ctx))
 
 			// run
 			if tt.expectRunErrorIs != nil {
 				err := bpipe.runAll(ctx, client)
-				require.ErrorAs(t, err, &tt.expectPublishErrorIs)
+				require.ErrorAs(t, err, &tt.expectRunErrorIs)
 				return
 			}
 			require.NoError(t, bpipe.runAll(ctx, client))
