@@ -28,6 +28,7 @@ var (
 	errSkipUpload               = pipe.Skip("winget.skip_upload is set")
 	errSkipUploadAuto           = pipe.Skip("winget.skip_upload is set to 'auto', and current version is a pre-release")
 	errMultipleArchives         = pipe.Skip("found multiple archives for the same platform, please consider filtering by id")
+	errMixedFormats             = pipe.Skip("found archives with multiple formats (.exe and .zip)")
 
 	// copied from winget src
 	packageIdentifierValid = regexp.MustCompile("^[^\\.\\s\\\\/:\\*\\?\"<>\\|\\x01-\\x1f]{1,32}(\\.[^\\.\\s\\\\/:\\*\\?\"<>\\|\\x01-\\x1f]{1,32}){1,7}$")
@@ -165,8 +166,13 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 
 	filters := []artifact.Filter{
 		artifact.ByGoos("windows"),
-		artifact.ByFormats("zip"),
-		artifact.ByType(artifact.UploadableArchive),
+		artifact.Or(
+			artifact.And(
+				artifact.ByFormats("zip"),
+				artifact.ByType(artifact.UploadableArchive),
+			),
+			artifact.ByType(artifact.UploadableBinary),
+		),
 		artifact.Or(
 			artifact.ByGoarch("386"),
 			artifact.ByGoarch("arm64"),
@@ -231,32 +237,33 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 		},
 	}
 
-	var amd64Count, i386count int
+	var amd64Count, i386count, zipCount, binaryCount int
 	for _, archive := range archives {
 		sha256, err := archive.Checksum("sha256")
 		if err != nil {
 			return err
 		}
-		var files []InstallerItemFile
-		folder := artifact.ExtraOr(*archive, artifact.ExtraWrappedIn, ".")
-		for _, bin := range artifact.ExtraOr(*archive, artifact.ExtraBinaries, []string{}) {
-			files = append(files, InstallerItemFile{
-				RelativeFilePath:     strings.ReplaceAll(filepath.Join(folder, bin), "/", "\\"),
-				PortableCommandAlias: strings.TrimSuffix(filepath.Base(bin), ".exe"),
-			})
-		}
 		url, err := tmpl.New(ctx).WithArtifact(archive).Apply(winget.URLTemplate)
 		if err != nil {
 			return err
 		}
-		installer.Installers = append(installer.Installers, InstallerItem{
-			Architecture:         fromGoArch[archive.Goarch],
-			NestedInstallerType:  "portable",
-			NestedInstallerFiles: files,
-			InstallerURL:         url,
-			InstallerSha256:      sha256,
-			UpgradeBehavior:      "uninstallPrevious",
-		})
+		item := InstallerItem{
+			Architecture:    fromGoArch[archive.Goarch],
+			InstallerURL:    url,
+			InstallerSha256: sha256,
+			UpgradeBehavior: "uninstallPrevious",
+		}
+		if archive.Format() == "zip" {
+			zipCount++
+			installer.InstallerType = "zip"
+			item.NestedInstallerType = "portable"
+			item.NestedInstallerFiles = installerItemFilesFor(*archive)
+		} else {
+			binaryCount++
+			installer.InstallerType = "portable"
+			installer.Commands = []string{winget.Name}
+		}
+		installer.Installers = append(installer.Installers, item)
 		switch archive.Goarch {
 		case "386":
 			i386count++
@@ -265,6 +272,10 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 		}
 	}
 
+	if binaryCount > 0 && zipCount > 0 {
+		return errMixedFormats
+	}
+
 	if i386count > 1 || amd64Count > 1 {
 		return errMultipleArchives
 	}
@@ -437,3 +448,15 @@ func repoFileID(tp artifact.Type) string {
 		return ""
 	}
 }
+
+func installerItemFilesFor(archive artifact.Artifact) []InstallerItemFile {
+	var files []InstallerItemFile
+	folder := artifact.ExtraOr(archive, artifact.ExtraWrappedIn, ".")
+	for _, bin := range artifact.ExtraOr(archive, artifact.ExtraBinaries, []string{}) {
+		files = append(files, InstallerItemFile{
+			RelativeFilePath:     strings.ReplaceAll(filepath.Join(folder, bin), "/", "\\"),
+			PortableCommandAlias: strings.TrimSuffix(filepath.Base(bin), ".exe"),
+		})
+	}
+	return files
+}
