@@ -156,6 +156,7 @@ type HomebrewDependency struct {
 	Name    string `yaml:"name,omitempty" json:"name,omitempty"`
 	Type    string `yaml:"type,omitempty" json:"type,omitempty"`
 	Version string `yaml:"version,omitempty" json:"version,omitempty"`
+	OS      string `yaml:"os,omitempty" json:"os,omitempty" jsonschema:"enum=mac,enum=linux"`
 }
 
 // type alias to prevent stack overflowing in the custom unmarshaler.
@@ -218,6 +219,7 @@ type AUR struct {
 	GitSSHCommand         string       `yaml:"git_ssh_command,omitempty" json:"git_ssh_command,omitempty"`
 	PrivateKey            string       `yaml:"private_key,omitempty" json:"private_key,omitempty"`
 	Goamd64               string       `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
+	Directory             string       `yaml:"directory,omitempty" json:"directory,omitempty"`
 }
 
 // Homebrew contains the brew section.
@@ -316,25 +318,25 @@ func (a *NixDependency) UnmarshalYAML(unmarshal func(interface{}) error) error {
 
 type Winget struct {
 	Name                  string             `yaml:"name,omitempty" json:"name,omitempty"`
-	PackageIdentifier     string             `yaml:"package_identifier,omitempty" json:"package_identifier,omitempty"`
-	Publisher             string             `yaml:"publisher,omitempty" json:"publisher,omitempty"`
+	PackageIdentifier     string             `yaml:"package_identifier" json:"package_identifier"`
+	Publisher             string             `yaml:"publisher" json:"publisher"`
 	PublisherURL          string             `yaml:"publisher_url,omitempty" json:"publisher_url,omitempty"`
 	PublisherSupportURL   string             `yaml:"publisher_support_url,omitempty" json:"publisher_support_url,omitempty"`
 	Copyright             string             `yaml:"copyright,omitempty" json:"copyright,omitempty"`
 	CopyrightURL          string             `yaml:"copyright_url,omitempty" json:"copyright_url,omitempty"`
 	Author                string             `yaml:"author,omitempty" json:"author,omitempty"`
 	Path                  string             `yaml:"path,omitempty" json:"path,omitempty"`
-	Repository            RepoRef            `yaml:"repository,omitempty" json:"repository,omitempty"`
+	Repository            RepoRef            `yaml:"repository" json:"repository"`
 	CommitAuthor          CommitAuthor       `yaml:"commit_author,omitempty" json:"commit_author,omitempty"`
 	CommitMessageTemplate string             `yaml:"commit_msg_template,omitempty" json:"commit_msg_template,omitempty"`
 	IDs                   []string           `yaml:"ids,omitempty" json:"ids,omitempty"`
 	Goamd64               string             `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
 	SkipUpload            string             `yaml:"skip_upload,omitempty" json:"skip_upload,omitempty" jsonschema:"oneof_type=string;boolean"`
 	URLTemplate           string             `yaml:"url_template,omitempty" json:"url_template,omitempty"`
-	ShortDescription      string             `yaml:"short_description,omitempty" json:"short_description,omitempty"`
+	ShortDescription      string             `yaml:"short_description" json:"short_description"`
 	Description           string             `yaml:"description,omitempty" json:"description,omitempty"`
 	Homepage              string             `yaml:"homepage,omitempty" json:"homepage,omitempty"`
-	License               string             `yaml:"license,omitempty" json:"license,omitempty"`
+	License               string             `yaml:"license" json:"license"`
 	LicenseURL            string             `yaml:"license_url,omitempty" json:"license_url,omitempty"`
 	ReleaseNotes          string             `yaml:"release_notes,omitempty" json:"release_notes,omitempty"`
 	ReleaseNotesURL       string             `yaml:"release_notes_url,omitempty" json:"release_notes_url,omitempty"`
